@@ -1326,16 +1326,17 @@ defmodule Code.Formatter do
               file: state.file,
               line: meta[:line],
               sigil: List.to_atom([name]),
-              modifiers: modifiers
+              modifiers: modifiers,
+              opening_delimiter: opening_delimiter
             ]
 
             case callback.(hd(entries), metadata) do
-              binary when is_binary(binary) ->
-                [binary]
+              iodata when is_binary(iodata) or is_list(iodata) ->
+                [IO.iodata_to_binary(iodata)]
 
               other ->
                 raise ArgumentError,
-                      "expected sigil callback to return a binary, got: #{inspect(other)}"
+                      "expected sigil callback to return iodata, got: #{inspect(other)}"
             end
 
           %{} ->
